==> billogram-foundation-2.3.5.tgz: package/modules/components/button/LinkButton.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import ButtonContent from './ButtonContent';

import isNullOrEmpty from '../../isNullOrEmpty';


export default ({
    block,
    displayName
}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    const Content = ButtonContent({ block, displayName: `${displayName}Content` });

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            children: PropTypes.node,
            disabled: PropTypes.bool,
            icon: PropTypes.string,
            target: PropTypes.string,
            to: PropTypes.string,
            ui: PropTypes.oneOfType([
                PropTypes.string,
                PropTypes.arrayOf(PropTypes.string)
            ])
        },

        getDefaultProps() {
            return {
                children: null,
                icon: null,
                stretched: false,
                target: null,
                to: '',
                ui: ''
            };
        },

        onClick(evt) {
            if (this.props.disabled) {
                evt.preventDefault();
            }
        },

        render() {
            const { children, disabled, icon, target, to, ui } = this.props;
            return (
                <a
                    className={ block({ disabled }, typeof ui === 'string' ? [ui] : ui) }
                    data-load="static"
                    href={ to }
                    onClick={ this.onClick }
                    target={ target }>
                    <Content
                        icon={ icon }>
                        { children }
                    </Content>
                </a>
            );
        }

    });

};

==> billogram-foundation-2.3.8.tgz: package/modules/components/button/LinkButton.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import ButtonContent from './ButtonContent';

import isNullOrEmpty from '../../isNullOrEmpty';
import getRootClassName from './utils/getRootClassName';


export default ({
    block,
    displayName
}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    const Content = ButtonContent({ block, displayName: `${displayName}Content` });

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            children: PropTypes.node,
            disabled: PropTypes.bool,
            icon: PropTypes.oneOf([
                PropTypes.string,
                PropTypes.shape({
                    name: PropTypes.string.isRequired,
                    direction: PropTypes.oneOf(['left', 'right'])
                })
            ]),
            target: PropTypes.string,
            to: PropTypes.string,
            ui: PropTypes.oneOfType([
                PropTypes.string,
                PropTypes.arrayOf(PropTypes.string)
            ])
        },

        getDefaultProps() {
            return {
                children: null,
                icon: null,
                stretched: false,
                target: null,
                to: '',
                ui: ''
            };
        },

        onClick(evt) {
            if (this.props.disabled) {
                evt.preventDefault();
            }
        },

        render() {
            const { children, disabled, icon, target, to, ui } = this.props;
            return (
                <a
                    className={ getRootClassName(block, { children, disabled, icon, ui }) }
                    data-load="static"
                    href={ to }
                    onClick={ this.onClick }
                    target={ target }>
                    <Content
                        icon={ icon }>
                        { children }
                    </Content>
                </a>
            );
        }

    });

};
